==> hubzero-use-apps_1.1.3.orig.tar.gz: hubzero-use-apps-1.1.3/apps.sh <==
# @package      hubzero-use-apps
# @file         apps.sh
# @author       Nicholas J. Kisseberth <nkissebe@purdue.edu>
# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#


CONFIG_DIRS=""


# determibe Debian OS version, 5 - lenny, 6 - squeeze, 7 - wheezy
dist=debian
os_version=$(grep Linux /etc/issue | sed -e "s/.*Linux //" -e "s/\.[0-9]*//" -e "s/ .*//")
dist_version=${dist}${os_version}

# setup the name of the share directory where external software
# should be installed.
# share_base is for bit ambiguous software (probably scripts)
# share_arch is for bit specific software (32-bit vs 64-bit compiled stuff)
share_base="share"
share_arch=""
if [ $(uname -m) = x86_64 ] ; then
    # setup for 64-bit share envionments
    share_arch="share64"
elif [ $(uname -m) = x86 ] ; then
    # setup for 32-bit share envionments
    share_arch="share32"
else
    share_arch="share"
fi


# setup bit specific share environments
if   [ -d /apps/${share_arch}/${dist_version}/environ.d ] ; then
    CONFIG_DIRS="$CONFIG_DIRS /apps/${share_arch}/${dist_version}/environ.d"
elif [ -d /apps/${share_arch}/environ.d ] ; then
    CONFIG_DIRS="$CONFIG_DIRS /apps/${share_arch}/environ.d"
elif [ -d /apps/${share_arch}/environ ] ; then
    CONFIG_DIRS="$CONFIG_DIRS /apps/${share_arch}/environ"
fi

if [ ${share_arch} != ${share_base} ] ; then
    # setup bit agnostic share environments
    if   [ -d /apps/${share_base}/${dist_version}/environ.d ] ; then
        CONFIG_DIRS="$CONFIG_DIRS /apps/${share_base}/${dist_version}/environ.d"
    elif [ -d /apps/${share_base}/environ.d ] ; then
        CONFIG_DIRS="$CONFIG_DIRS /apps/${share_base}/environ.d"
    elif [ -d /apps/${share_base}/environ ] ; then
        CONFIG_DIRS="$CONFIG_DIRS /apps/${share_base}/environ"
    fi
fi


# special setup for old production machines
if [ ${dist_version} = debian5 ] ; then
    # take care of debian 5 (lenny) installs on old production machines
    # during transition, these may exist in cooperation with one of the
    # previous bit specific environments. if we are operating in one
    # of these environments, we ignore previous CONFIG_DIRS settings
    # and hard code to use the old location.
    CONFIG_DIRS=""
    if   [ -d /apps/environ.d ] ; then
        CONFIG_DIRS="$CONFIG_DIRS /apps/environ.d"
    elif [ -d /apps/environ ] ; then
        CONFIG_DIRS="$CONFIG_DIRS /apps/environ"
    fi
fi


ENVIRON_CONFIG_DIRS="$ENVIRON_CONFIG_DIRS $CONFIG_DIRS"
export ENVIRON_CONFIG_DIRS

==> hubzero-use-apps_1.2.0.orig.tar.gz: hubzero-use-apps-1.2.0/apps.sh <==
# @package      hubzero-use-apps
# @file         apps.sh
# @author       Nicholas J. Kisseberth <nkissebe@purdue.edu>
# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
#
# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
#
# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
#
# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
# software: you can redistribute it and/or modify it under the terms of
# the GNU Lesser General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# HUBzero is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
# HUBzero is a registered trademark of HUBzero Foundation, LLC.
#


CONFIG_DIRS=""

isDebian=$(grep -c "Debian" /etc/issue)
isRhel=$(grep -c "Red Hat" /etc/issue)

if [ ${isDebian} -eq 1 ] ; then
   # determibe Debian OS version, 5 - lenny, 6 - squeeze, 7 - wheezy
   dist=debian
   os_version=$(grep Linux /etc/issue | sed -e "s/.*Linux //" -e "s/\.[0-9]*//" -e "s/ .*//")
fi
if [ ${isRhel} -eq 1 ] ; then
   # determibe Red Hat OS version
   dist=rhel
   os_version=$(grep Linux /etc/issue | sed -e "s/\.[0-9]* \(.*\)//" -e "s/.* //")
fi
dist_version=${dist}${os_version}

# setup the name of the share directory where external software
# should be installed.
# share_base is for bit ambiguous software (probably scripts)
# share_arch is for bit specific software (32-bit vs 64-bit compiled stuff)
share_base="share"
share_arch=""
if [ $(uname -m) = x86_64 ] ; then
    # setup for 64-bit share envionments
    share_arch="share64"
elif [ $(uname -m) = x86 ] ; then
    # setup for 32-bit share envionments
    share_arch="share32"
else
    share_arch="share"
fi


# setup bit specific share environments
if   [ -d /apps/${share_arch}/${dist_version}/environ.d ] ; then
    CONFIG_DIRS="$CONFIG_DIRS /apps/${share_arch}/${dist_version}/environ.d"
elif [ -d /apps/${share_arch}/environ.d ] ; then
    CONFIG_DIRS="$CONFIG_DIRS /apps/${share_arch}/environ.d"
elif [ -d /apps/${share_arch}/environ ] ; then
    CONFIG_DIRS="$CONFIG_DIRS /apps/${share_arch}/environ"
fi

if [ ${share_arch} != ${share_base} ] ; then
    # setup bit agnostic share environments
    if   [ -d /apps/${share_base}/${dist_version}/environ.d ] ; then
        CONFIG_DIRS="$CONFIG_DIRS /apps/${share_base}/${dist_version}/environ.d"
    elif [ -d /apps/${share_base}/environ.d ] ; then
        CONFIG_DIRS="$CONFIG_DIRS /apps/${share_base}/environ.d"
    elif [ -d /apps/${share_base}/environ ] ; then
        CONFIG_DIRS="$CONFIG_DIRS /apps/${share_base}/environ"
    fi
fi


# special setup for old production machines
if [ ${dist_version} = debian5 ] ; then
    # take care of debian 5 (lenny) installs on old production machines
    # during transition, these may exist in cooperation with one of the
    # previous bit specific environments. if we are operating in one
    # of these environments, we ignore previous CONFIG_DIRS settings
    # and hard code to use the old location.
    CONFIG_DIRS=""
    if   [ -d /apps/environ.d ] ; then
        CONFIG_DIRS="$CONFIG_DIRS /apps/environ.d"
    elif [ -d /apps/environ ] ; then
        CONFIG_DIRS="$CONFIG_DIRS /apps/environ"
    fi
fi


ENVIRON_CONFIG_DIRS="$ENVIRON_CONFIG_DIRS $CONFIG_DIRS"
export ENVIRON_CONFIG_DIRS
